pub async fn record(rx: StreamReceiver) -> RecordingExpand description
Drain a StreamReceiver into a Recording, timestamping each event from the start.
pub async fn record(rx: StreamReceiver) -> RecordingDrain a StreamReceiver into a Recording, timestamping each event from the start.